## 5.2.0.20260402 (2026-04-02)

Update mypy to 1.20.0 ([#15588](https://github.com/python/typeshed/pull/15588))

## 5.2.0.20250924 (2025-09-24)

[mock] Sync _ANY type with unittest.mock ([#14772](https://github.com/python/typeshed/pull/14772))

## 5.2.0.20250809 (2025-08-09)

Mark stub-only private symbols as `@type_check_only` in third-party stubs ([#14545](https://github.com/python/typeshed/pull/14545))

## 5.2.0.20250516 (2025-05-16)

Replace `Incomplete | None = None` in third party stubs ([#14063](https://github.com/python/typeshed/pull/14063))

## 5.2.0.20250306 (2025-03-06)

Bump mock to 5.2.* ([#13581](https://github.com/python/typeshed/pull/13581))

## 5.1.0.20240425 (2024-04-25)

Bump pyright to v1.1.360 ([#11810](https://github.com/python/typeshed/pull/11810))

## 5.1.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs ([#11554](https://github.com/python/typeshed/pull/11554))

## 5.1.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs ([#11245](https://github.com/python/typeshed/pull/11245))

Remove Python 3.7 branches ([#11238](https://github.com/python/typeshed/pull/11238))

## 5.1.0.3 (2023-11-24)

Third-party stubs: remove unused `type: ignore`s ([#11063](https://github.com/python/typeshed/pull/11063))

## 5.1.0.2 (2023-09-02)

Update `unittest.mock` to 3.12 ([#10650](https://github.com/python/typeshed/pull/10650))

And harmonise some annotations between the stdlib `unittest.mock` module and the third-party `mock` backport package.

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 5.1.0.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml ([#10487](https://github.com/python/typeshed/pull/10487))

Closes: #10478

## 5.1.0.0 (2023-07-19)

Add a more precise signature for `AsyncMock.reset_mock()` ([#10481](https://github.com/python/typeshed/pull/10481))

Update `mock` to `5.1.*` ([#10472](https://github.com/python/typeshed/pull/10472))

## 5.0.0.7 (2023-06-21)

[mock] take an iterable of calls for assert_has_awaits([#10337](https://github.com/python/typeshed/pull/10337))

use ParamSpec in patch in mock stubs ([#10338](https://github.com/python/typeshed/pull/10338))

## 5.0.0.6 (2023-03-27)

Add defaults for third-party stubs M-O ([#9956](https://github.com/python/typeshed/pull/9956))

## 5.0.0.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` ([#9779](https://github.com/python/typeshed/pull/9779))

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 5.0.0.4 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` ([#9702](https://github.com/python/typeshed/pull/9702))

## 5.0.0.3 (2023-02-14)

Add comments when subclassing Any ([#9732](https://github.com/python/typeshed/pull/9732))

## 5.0.0.2 (2023-01-18)

Replace `Any` with `Incomplete` in many places ([#9565](https://github.com/python/typeshed/pull/9565))

## 5.0.0.1 (2023-01-18)

Replace `Any` with `Incomplete` in many places ([#9558](https://github.com/python/typeshed/pull/9558))

## 5.0.0.0 (2023-01-04)

Bump mock to 5.0.* ([#9423](https://github.com/python/typeshed/pull/9423))

## 4.0.15.2 (2022-10-20)

Remove `mock` from `pyright`'s exclude ([#8942](https://github.com/python/typeshed/pull/8942))

## 4.0.15.1 (2022-10-19)

Mark `mock` as completed ([#8919](https://github.com/python/typeshed/pull/8919))

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 4.0.15 (2022-06-06)

Always use `TypeAlias` when assigning to `Any` ([#8021](https://github.com/python/typeshed/pull/8021))

## 4.0.14 (2022-05-25)

mock: Fix unconstrained TypeVar ([#7945](https://github.com/python/typeshed/pull/7945))

The first overload covers the case where `new` is not given.

Part of #7928

## 4.0.13 (2022-04-01)

Third-party stubs: Improve several `__exit__` methods ([#7575](https://github.com/python/typeshed/pull/7575))

## 4.0.12 (2022-03-19)

Add mypy error codes to `type: ignore`s, remove unused ignores ([#7504](https://github.com/python/typeshed/pull/7504))

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 4.0.11 (2022-02-22)

Correct several positional-only differences in third-party stubs ([#7352](https://github.com/python/typeshed/pull/7352))

## 4.0.10 (2022-02-03)

Improve `__enter__` & constructor methods ([#7114](https://github.com/python/typeshed/pull/7114))

## 4.0.9 (2022-01-30)

Reduce use of `Any` in equality methods ([#7081](https://github.com/python/typeshed/pull/7081))

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 4.0.8 (2022-01-08)

Use lowercase `type` everywhere ([#6853](https://github.com/python/typeshed/pull/6853))

## 4.0.7 (2022-01-07)

Update pyright ([#6840](https://github.com/python/typeshed/pull/6840))

## 4.0.5 (2021-12-25)

Fixes for third-party mock package ([#6685](https://github.com/python/typeshed/pull/6685))

Removed a few unused private classes and methods. They can be re-added if a user reports them missing.

## 4.0.4 (2021-11-26)

Add mypy error codes to '# type: ignore' comments ([#6379](https://github.com/python/typeshed/pull/6379))

## 4.0.3 (2021-10-15)

Use lowercase tuple where possible ([#6170](https://github.com/python/typeshed/pull/6170))

## 4.0.2 (2021-10-12)

Add star to all non-0.1 versions ([#6146](https://github.com/python/typeshed/pull/6146))

